<?php

/**
 * This file is part of the MADIS - RGPD Management application.
 *
 * @copyright Copyright (c) 2018-2019 Soluris - Solutions Numériques Territoriales Innovantes
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

declare(strict_types=1);

namespace App\Tests\Domain\User\Validator\Constraints;

use App\Domain\User\Validator\Constraints\CustomPassword;
use App\Domain\User\Validator\Constraints\CustomPasswordValidator;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Test\ConstraintValidatorTestCase;

class CustomPasswordValidatorTest extends ConstraintValidatorTestCase
{
    protected function createValidator(): ConstraintValidator
    {
        return new CustomPasswordValidator(
            15,
            true,
            true,
            true,
            true
        );
    }

    public function testValidValues(): void
    {
        $this->validator->validate('@1azefreEgtrfduytrezuytre', new CustomPassword());
        $this->assertNoViolation();
    }

    public function testInvalidValues(): void
    {
        $constraint = new CustomPassword();

        $this->validator->validate('InvalidValue', $constraint);
        $this
            ->buildViolation($constraint->tooShortMessage)
            ->setParameter('{{length}}', '15')
            ->buildNextViolation($constraint->missingNumbersMessage)
            ->buildNextViolation($constraint->missingSpecialCharacterMessage)
            ->assertRaised();
    }
}
